#ifndef OSL_HANDICAP_H
#define OSL_HANDICAP_H
namespace osl{
  enum Handicap{
    HIRATE,
    //    KYOUOCHI,
    //    KAKUOCHI,
  };
}
#endif // OSL_HANDICAP_H
